@@ -1,5 +1,8 @@
 from spatialmath.pose2d import *
 from spatialmath.pose3d import *
+from spatialmath.geom3d import *
 from spatialmath.quaternion import *
 from spatialmath.super_pose import *
+from spatialmath.super_pose import _color
 from spatialmath import base
+#from spatialmath.Plucker import *
