@@ -44,6 +44,7 @@ import numpy as np
 from spatialmath.base import argcheck
 from spatialmath.base import vectors as vec
 from spatialmath.base import transformsNd as trn
+import scipy.linalg
 
 try:  # pragma: no cover
     #print('Using SymPy')
@@ -209,7 +210,44 @@ def isrot2(R, check=False):
     """
     return isinstance(R, np.ndarray) and R.shape == (2, 2) and (not check or trn.isR(R))
 
+# ---------------------------------------------------------------------------------------#
+def trlog2(T, check=True):
+    """
+    Logarithm of SO(2) or SE(2) matrix
 
+    :param T: SO(2) or SE(2) matrix
+    :type T: numpy.ndarray, shape=(2,2) or (3,3)
+    :return: logarithm
+    :rtype: numpy.ndarray, shape=(2,2) or (3,3)
+    :raises: ValueError
+
+    An efficient closed-form solution of the matrix logarithm for arguments that are SO(2) or SE(2).
+
+    - ``trlog2(R)`` is the logarithm of the passed rotation matrix ``R`` which will be
+      2x2 skew-symmetric matrix.  The equivalent vector from ``vex()`` is parallel to rotation axis
+      and its norm is the amount of rotation about that axis.
+    - ``trlog(T)`` is the logarithm of the passed homogeneous transformation matrix ``T`` which will be
+      3x3 augumented skew-symmetric matrix. The equivalent vector from ``vexa()`` is the twist
+      vector (6x1) comprising [v w].
+
+
+    :seealso: :func:`~trexp`, :func:`~spatialmath.base.transformsNd.vex`, :func:`~spatialmath.base.transformsNd.vexa`
+    """
+
+    if ishom2(T, check=check):
+        # SE(2) matrix
+
+        if trn.iseye(T):
+            # is identity matrix
+            return np.zeros((3,3))
+        else:
+            return scipy.linalg.logm(T)
+
+    elif isrot2(T, check=check):
+        # SO(2) rotation matrix
+        return scipy.linalg.logm(T)
+    else:
+        raise ValueError("Expect SO(2) or SE(2) matrix")
 # ---------------------------------------------------------------------------------------#
 def trexp2(S, theta=None):
     """
@@ -264,6 +302,9 @@ def trexp2(S, theta=None):
             # 3 vector
             tw = argcheck.getvector(S)
 
+        if vec.iszerovec(tw):
+            return np.eye(3)
+        
         if theta is None:
             (tw, theta) = vec.unittwist2(tw)
         else:
@@ -296,109 +337,77 @@ def trexp2(S, theta=None):
     else:
         raise ValueError(" First argument must be SO(2), 1-vector, SE(2) or 3-vector")
         
-def trinterp2(T0, T1=None, s=None):
+def trinterp2(end, start=None, s=None):
     """
     Interpolate SE(2) matrices
 
-    :param T0: first SE(2) matrix
+    :param end: final SE(3) matrix, value when s=1
     :type T0: np.ndarray, shape=(3,3)
-    :param T1: second SE(2) matrix
+    :param start: initial SE(3) matrix, value when s=0, optional, defaults to identity
     :type T1: np.ndarray, shape=(3,3)
     :param s: interpolation coefficient, range 0 to 1
     :type s: float
     :return: SE(2) matrix
     :rtype: np.ndarray, shape=(3,3)
     
-    - ``trinterp2(T0, T1, S)`` is a homogeneous transform (3x3) interpolated
-    between T0 when S=0 and T1 when S=1.  T0 and T1 are both homogeneous
-    transforms (3x3).
+    - ``trinterp2(T1, s=S)`` is a homogeneous transform (3x3) interpolated
+      between identity when S=0 and T1 when S=1.
+      
+    - ``trinterp2(T1, start=T0, s=S)`` as above but interpolated
+      between T0 when S=0 and T1 when S=1.  T0 and T1 are both homogeneous
+      transforms (3x3).
     
-    - ``trinterp2(T1, S)`` as above but interpolated between the identity matrix
-    when S=0 to T1 when S=1.
-    
-    Notes::
+    Notes:
+        
     - Rotation angle is linearly interpolated.
 
     :seealso: :func:`~spatialmath.base.transforms3d.trinterp`
     
     %## 2d homogeneous trajectory
     """
-    if T1 is None:
-        #	TRINTERP2(T, s)
+    if argcheck.ismatrix(start, (2,2)):
+        # SO(2) case
+        if T1 is None:
+            #	TRINTERP2(T, s)
+            
+            th0 = math.atan2(start[1,0], start[0,0])
+            
+            th = s * th0
+        else:
+            #	TRINTERP2(T0, T1, s)
+            assert start.shape == end.shape, 'both matrices must be same shape'
         
-        th0 = math.atan2(T0[1,0], T0[0,0])
-        p0 = transl2(T0)
+            th0 = math.atan2(start[1,0], start[0,0])
+            th1 = math.atan2(end[1,0], end[0,0])
+            
+            th = th0 * (1 - s) + s * th1
         
-        th = s * th0
-        pr = s * p0
+        return rot2(th)
+    elif argcheck.ismatrix(start, (3,3)):
+        if end is None:
+            #	TRINTERP2(T, s)
+            
+            th0 = math.atan2(start[1,0], start[0,0])
+            p0 = transl2(start)
+            
+            th = s * th0
+            pr = s * p0
+        else:
+            #	TRINTERP2(T0, T1, s)
+            assert start.shape == end.shape, 'both matrices must be same shape'
+        
+            th0 = math.atan2(start[1,0], start[0,0])
+            th1 = math.atan2(end[1,0], end[0,0])
+            
+            p0 = transl2(start)
+            p1 = transl2(end)
+            
+            pr = p0 * (1 - s) + s * p1;
+            th = th0 * (1 - s) + s * th1
+        
+        return trn.rt2tr(rot2(th), pr)
     else:
-        #	TRINTERP2(T0, T1, s)
-    
-        th0 = math.atan2(T0[1,0], T0[0,0])
-        th1 = math.atan2(T1[1,0], T1[0,0])
-        
-        p0 = transl2(T0)
-        p1 = transl2(T1)
-        
-        pr = p0 * (1 - s) + s * p1;
-        th = th0 * (1 - s) + s * th1
-    
-    return trn.rt2tr(rot2(th), pr)
-
-
-# function T = trinterp2(A, B, C)
-
-#     switch nargin
-#         case 2
-#             % trinterp(T, s)
-#             T1 = A; s = B;
-            
-#             th0 = 0;
-#             th1 = atan2(T1(2,1), T1(1,1));
-#             if ~isrot2(T1)
-#                 p0 = [0 0]';
-#                 p1 = transl2(T1);
-#             end
-#         case 3
-#             % trinterp(T1, T2, s)
-#             T0 = A; T1 = B; s = C;
-#             assert(all(size(A) == size(B)), 'SMTB:trinterp2:badarg', '2 matrices must be same size');
-#             th0 = atan2(T0(2,1), T0(1,1));
-#             th1 = atan2(T1(2,1), T1(1,1));
-#             if ~isrot2(T0)
-#                 p0 = transl2(T0);
-#                 p1 =transl2(T1);
-#             end
-#         otherwise
-#             error('SMTB:trinterp2:badarg', 'must be 2 or 3 arguments');
-#     end
-    
-#     if length(s) == 1 && s > 1 && (s == floor(s))
-#         % integer value
-#         s = [0:(s-1)] / (s-1);
-#     elseif any(s<0 | s>1)
-#         error('SMTB:trinterp2:badarg', 'values of S outside interval [0,1]');
-#     end
-    
-#     if isrot2(T1)
-        
-#         % SO(2) case
-#         for i=1:length(s)
-#             th = th0*(1-s(i)) + s(i)*th1;
-            
-#             T(:,:,i) = rot2(th);
-#         end
-#     else
-#         % SE(2) case
-#         for i=1:length(s)
-#             th = th0*(1-s(i)) + s(i)*th1;
-#             pr = p0*(1-s(i)) + s(i)*p1;
-            
-#             T(:,:,i) = rt2tr(rot2(th), pr);
-#         end
-#     end
-    
-# end
+        return ValueError('Argument must be SO(2) or SE(2)')
 
 
 def trprint2(T, label=None, file=sys.stdout, fmt='{:8.2g}', unit='deg'):
@@ -415,27 +424,27 @@ def trprint2(T, label=None, file=sys.stdout, fmt='{:8.2g}', unit='deg'):
     :type fmt: str
     :param unit: angular units: 'rad' [default], or 'deg'
     :type unit: str
-    :return: optional formatted string
+    :return: formatted string
     :rtype: str
 
-    The matrix is formatted and written to ``file`` or if ``file=None`` then the
-    string is returned.
+    The matrix is formatted and written to ``file`` and the
+    string is returned.  To suppress writing to a file, set ``file=None``.
 
     - ``trprint2(R)`` displays the SO(2) rotation matrix in a compact
-      single-line format:
+      single-line format and returns the string::
 
         [LABEL:] THETA UNIT
 
     - ``trprint2(T)`` displays the SE(2) homogoneous transform in a compact
-      single-line format:
+      single-line format and returns the string::
 
         [LABEL:] [t=X, Y;] THETA UNIT
 
-    Example:
+    Example::
 
-    >>> T = transl2(1,2)@trot2(0.3)
-    >>> trprint2(a, file=None, label='T')
-    'T: t =        1,        2;       17 deg'
+        >>> T = transl2(1,2) @ trot2(0.3)
+        >>> trprint2(a, file=None, label='T')
+        'T: t =        1,        2;       17 deg'
 
     :seealso: trprint
     """
@@ -446,7 +455,8 @@ def trprint2(T, label=None, file=sys.stdout, fmt='{:8.2g}', unit='deg'):
         s += '{:s}: '.format(label)
 
     # print the translational part if it exists
-    s += 't = {};'.format(_vec2s(fmt, transl2(T)))
+    if ishom2(T):
+        s += 't = {};'.format(_vec2s(fmt, transl2(T)))
 
     angle = math.atan2(T[1, 0], T[0, 0])
     if unit == 'deg':
@@ -455,8 +465,7 @@ def trprint2(T, label=None, file=sys.stdout, fmt='{:8.2g}', unit='deg'):
 
     if file:
         print(s, file=file)
-    else:
-        return s
+    return s
 
 
 def _vec2s(fmt, v):
@@ -466,15 +475,26 @@ def _vec2s(fmt, v):
 
 try:
     import matplotlib.pyplot as plt
+    from mpl_toolkits.mplot3d import Axes3D
+    _matplotlib_exists = True
+    
+except BaseException:  # pragma: no cover
+    def trplot(*args, **kwargs):
+        print('matplotlib is not installed: pip install matplotlib')
+    _matplotlib_exists = False
+        
+if _matplotlib_exists:
 
-    def trplot2(T, ax=None, dims=None, color='blue', frame=None, textcolor=None, labels=['X', 'Y'], length=1, arrow=True, rviz=False, wtl=0.2, width=1, d1=0.05, d2=1.15):
+    def trplot2(T, axes=None, block=True, dims=None, color='blue', frame=None, textcolor=None, labels=['X', 'Y'], length=1, arrow=True, rviz=False, wtl=0.2, width=1, d1=0.05, d2=1.15, **kwargs):
         """
         Plot a 2D coordinate frame
 
         :param T: an SO(3) or SE(3) pose to be displayed as coordinate frame
         :type: numpy.ndarray, shape=(2,2) or (3,3)
-        :param X: the axes to plot into, defaults to current axes
-        :type ax: Axes3D reference
+        :param axes: the axes to plot into, defaults to current axes
+        :type axes: Axes3D reference
+        :param block: run the GUI main loop until all windows are closed, default True
+        :type block: bool
         :param dims: dimension of plot volume as [xmin, xmax, ymin, ymax]
         :type dims: array_like
         :param color: color of the lines defining the frame
@@ -499,6 +519,8 @@ try:
         :type width: float
         :param d1: distance of frame axis label text from origin, default 1.15
         :type d2: distance of frame label text from origin, default 0.05
+        :return: axes containing the frame
+        :rtype: AxesSubplot
 
         Adds a 2D coordinate frame represented by the SO(2) or SE(2) matrix to the current axes.
 
@@ -523,7 +545,7 @@ try:
         else:
             assert ishom2(T, check=True)
 
-        if ax is None:
+        if axes is None:
             # create an axes
             fig = plt.gcf()
             if fig.axes == []:
@@ -533,6 +555,8 @@ try:
                 if dims is None:
                     ax.autoscale(enable=True, axis='both')
                 else:
+                    if len(dims) == 2:
+                        dims = dims * 2
                     ax.set_xlim(dims[0:2])
                     ax.set_ylim(dims[2:4])
                 ax.set_aspect('equal')
@@ -541,6 +565,8 @@ try:
             else:
                 # reuse an existing axis
                 ax = plt.gca()
+        else:
+            ax = axes
 
         # create unit vectors in homogeneous form
         o = T @ np.array([0, 0, 1])
@@ -577,9 +603,43 @@ try:
             ax.text(x[0], x[1], "$%c_{%s}$" % (labels[0], frame), color=color, horizontalalignment='center', verticalalignment='center')
             ax.text(y[0], y[1], "$%c_{%s}$" % (labels[1], frame), color=color, horizontalalignment='center', verticalalignment='center')
 
-except BaseException:  # pragma: no cover
-    def trplot2(*args, **kwargs):
-        print('** trplot2: no plot produced -- matplotlib not installed')
+        if block:
+            # calling this at all, causes FuncAnimation to fail so when invoked from tranimate2 skip this bit
+            plt.show(block=block)
+        return ax
+
+    from spatialmath.base import animate as animate
+    
+    def tranimate2(T, **kwargs):
+        """
+        Animate a 2D coordinate frame
+    
+        :param T: an SO(2) or SE(2) pose to be displayed as coordinate frame
+        :type: numpy.ndarray, shape=(2,2) or (3,3)
+        :param nframes: number of steps in the animation [defaault 100]
+        :type nframes: int
+        :param repeat: animate in endless loop [default False]
+        :type repeat: bool
+        :param interval: number of milliseconds between frames [default 50]
+        :type interval: int
+        :param movie: name of file to write MP4 movie into
+        :type movie: str
+        
+        Animates a 2D coordinate frame moving from the world frame to a frame represented by the SO(2) or SE(2) matrix to the current axes.
+    
+        - If no current figure, one is created
+        - If current figure, but no axes, a 3d Axes is created
+        
+    
+        Examples:
+    
+             tranimate2(transl(1,2)@trot2(1), frame='A', arrow=False, dims=[0, 5])
+             tranimate2(transl(1,2)@trot2(1), frame='A', arrow=False, dims=[0, 5], movie='spin.mp4')
+        """
+        anim = animate.Animate2(**kwargs)
+        anim.trplot2(T, **kwargs)
+        anim.run(**kwargs)
+
 
 if __name__ == '__main__':  # pragma: no cover
     import pathlib
