@@ -950,8 +950,8 @@ def trlog(T, check=True):
             # matrix is identity
             return np.zeros((3, 3))
         elif abs(np.trace(R) + 1) < 100 * _eps:
-
-            # rotation by +/- pi, +/- 3pi etc.
+            # check for trace = -1
+            #   rotation by +/- pi, +/- 3pi etc.
             diagonal = R.diagonal()
             k = diagonal.argmax()
             mx = diagonal[k]
@@ -1073,22 +1073,20 @@ def trnorm(T):
     :rtype: np.ndarray, shape=(3,3) or (4,4)
 
     - ``trnorm(R)`` is guaranteed to be a proper orthogonal matrix rotation
-    matrix (3x3) which is "close" to the input matrix R (3x3). If R
-    = [N,O,A] the O and A vectors are made unit length and the normal vector
-    is formed from N = O x A, and then we ensure that O and A are orthogonal
-    by O = A x N.
+      matrix (3x3) which is "close" to the input matrix R (3x3). If R
+      = [N,O,A] the O and A vectors are made unit length and the normal vector
+      is formed from N = O x A, and then we ensure that O and A are orthogonal
+      by O = A x N.
     
     - ``trnorm(T)`` as above but the rotational submatrix of the homogeneous
-    transformation T (4x4) is normalised while the translational part is
-    unchanged.
+      transformation T (4x4) is normalised while the translational part is
+      unchanged.
 
-    If R (3x3xK) or T (4x4xK) representing a sequence then the normalisation
-    is performed on each of the K planes.
-
-    Notes::
+    Notes:
+        
     - Only the direction of A (the z-axis) is unchanged.
     - Used to prevent finite word length arithmetic causing transforms to 
-    become `unnormalized'.
+      become 'unnormalized'.
     """
 
     assert ishom(T) or isrot(T), 'expecting 3x3 or 4x4 hom xform'
@@ -1105,26 +1103,24 @@ def trnorm(T):
     else:
         return R
     
-def trinterp(T0, T1=None, s=None):
+def trinterp(end, start=None, s=None):
     """
     Interpolate SE(3) matrices
     
-    :param T0: first SE(3) matrix
-    :type T0: np.ndarray, shape=(4,4)
-    :param T1: second SE(3) matrix
-    :type T1: np.ndarray, shape=(4,4)
+    :param end: final SE(3) matrix, value when s=1
+    :type end: np.ndarray, shape=(4,4)
+    :param start: initial SE(3) matrix, value when s=0, optional, defaults to identity
+    :type start: np.ndarray, shape=(4,4)
     :param s: interpolation coefficient, range 0 to 1
     :type s: float
     :return: SE(3) matrix
     :rtype: np.ndarray, shape=(4,4)
     
-    - ``trinterp(T0, T1, S)`` is a homogeneous transform (4x4) interpolated
-    between T0 when S=0 and T1 when S=1.  T0 and T1 are both homogeneous
-    transforms (4x4).
-    
-    - ``trinterp(T1, S)`` as above but interpolated between the identity matrix
-    when S=0 to T1 when S=1.
-    
+    - ``trinterp(T1, s=S)`` is a homogeneous transform (4x4) interpolated
+      between identity when S=0 and T1 when S=1.
+    - ``trinterp(T1, start=T0, s=S)`` as above but interpolated
+      between T0 when S=0 and T1 when S=1.  T0 and T1 are both homogeneous
+      transforms (4x4).
     
     Notes:
         
@@ -1135,22 +1131,22 @@ def trinterp(T0, T1=None, s=None):
 
     assert 0 <= s <= 1, 's outside interval [0,1]'
     
-    if T1 is None:
+    if end is None:
         #	TRINTERP(T, s)
         
-        q0 = quat.r2q(trn.t2r(T0))
-        p0 = transl(T0)
+        q0 = quat.r2q(trn.t2r(start))
+        p0 = transl(start)
         
         qr = quat.slerp(quat.eye(), q0, s)
         pr = s * p0
     else:
         #	TRINTERP(T0, T1, s)
     
-        q0 = quat.r2q(trn.t2r(T0))
-        q1 = quat.r2q(trn.t2r(T1))
+        q0 = quat.r2q(trn.t2r(start))
+        q1 = quat.r2q(trn.t2r(end))
         
-        p0 = transl(T0)
-        p1 = transl(T1)
+        p0 = transl(start)
+        p1 = transl(end)
         
         qr = quat.slerp(q0, q1, s)
         pr = p0 * (1 - s) + s * p1;
@@ -1207,9 +1203,9 @@ def tr2delta(T0, T1=None):
 
 
     - ``tr2delta(T0, T1)`` is the differential motion (6x1) corresponding to 
-    infinitessimal motion (in the T0 frame) from pose T0 to T1 which are SE(3) matrices.
+      infinitessimal motion (in the T0 frame) from pose T0 to T1 which are SE(3) matrices.
 
-    - ``tr2delta(T) as above but the motion is from the world frame to the pose represented by T.
+    - ``tr2delta(T)`` as above but the motion is from the world frame to the pose represented by T.
 
     The vector :math:`d = [\delta_x, \delta_y, \delta_z, \theta_x, \theta_y, \theta_z`
     represents infinitessimal translation and rotation, and is an approximation to the 
@@ -1286,11 +1282,11 @@ def trprint(T, orient='rpy/zyx', label=None, file=sys.stdout, fmt='{:8.2g}', uni
     :type fmt: str
     :param unit: angular units: 'rad' [default], or 'deg'
     :type unit: str
-    :return: optional formatted string
+    :return: formatted string
     :rtype: str
 
-    The matrix is formatted and written to ``file`` or if ``file=None`` then the
-    string is returned.
+    The matrix is formatted and written to ``file`` and the
+    string is returned.  To suppress writing to a file, set ``file=None``.
 
    - ``trprint(R)`` displays the SO(3) rotation matrix in a compact
       single-line format:
@@ -1368,8 +1364,8 @@ def trprint(T, orient='rpy/zyx', label=None, file=sys.stdout, fmt='{:8.2g}', uni
 
     if file:
         print(s, file=file)
-    else:
-        return s
+
+    return s
 
 
 def _vec2s(fmt, v):
@@ -1380,15 +1376,15 @@ def _vec2s(fmt, v):
 try:
     import matplotlib.pyplot as plt
     from mpl_toolkits.mplot3d import Axes3D
-    matplotlib_exists = True
+    _matplotlib_exists = True
     
 except BaseException:  # pragma: no cover
     def trplot(*args, **kwargs):
-        print('** trplot: no plot produced -- matplotlib not installed')
-    matplotlib_exists = False
+        print('matplotlib is not installed: pip install matplotlib')
+    _matplotlib_exists = False
         
-if matplotlib_exists:
-    def trplot(T, axes=None, dims=None, color='blue', frame=None, textcolor=None, labels=['X', 'Y', 'Z'], length=1, arrow=True, projection='ortho', rviz=False, wtl=0.2, width=1, d1=0.05, d2=1.15, **kwargs):
+if _matplotlib_exists:
+    def trplot(T, axes=None, block=True, dims=None, color='blue', frame=None, textcolor=None, labels=['X', 'Y', 'Z'], length=1, arrow=True, projection='ortho', rviz=False, wtl=0.2, width=1, d1=0.05, d2=1.15, **kwargs):
         """
         Plot a 3D coordinate frame
 
@@ -1396,8 +1392,10 @@ if matplotlib_exists:
         :type: numpy.ndarray, shape=(3,3) or (4,4)
         :param axes: the axes to plot into, defaults to current axes
         :type axes: Axes3D reference
+        :param block: run the GUI main loop until all windows are closed, default True
+        :type block: bool
         :param dims: dimension of plot volume as [xmin, xmax, ymin, ymax,zmin, zmax].
-        If dims is [min, max] those limits are applied to the x-, y- and z-axes.
+                     If dims is [min, max] those limits are applied to the x-, y- and z-axes.
         :type dims: array_like
         :param color: color of the lines defining the frame
         :type color: str
@@ -1421,6 +1419,8 @@ if matplotlib_exists:
         :type width: float
         :param d1: distance of frame axis label text from origin, default 1.15
         :type d2: distance of frame label text from origin, default 0.05
+        :return: axes containing the frame
+        :rtype: Axes3DSubplot
 
         Adds a 3D coordinate frame represented by the SO(3) or SE(3) matrix to the current axes.
 
@@ -1510,6 +1510,11 @@ if matplotlib_exists:
             ax.text(x[0], x[1], x[2], "$%c_{%s}$" % (labels[0], frame), color=color, horizontalalignment='center', verticalalignment='center')
             ax.text(y[0], y[1], y[2], "$%c_{%s}$" % (labels[1], frame), color=color, horizontalalignment='center', verticalalignment='center')
             ax.text(z[0], z[1], z[2], "$%c_{%s}$" % (labels[2], frame), color=color, horizontalalignment='center', verticalalignment='center')
+        
+        if block:
+            # calling this at all, causes FuncAnimation to fail so when invoked from tranimate skip this bit
+            plt.show(block=block)
+        return ax
 
     from spatialmath.base import animate as animate
 
