@@ -1,4 +1,5 @@
 import numpy.testing as nt
+import matplotlib.pyplot as plt
 import unittest
 
 """
@@ -16,6 +17,10 @@ def array_compare(x, y):
         x = x.A
     if isinstance(y, sp.SMPose):
         y = y.A
+    if isinstance(x, sp.SMTwist):
+        x = x.S
+    if isinstance(y, sp.SMTwist):
+        y = y.S
     nt.assert_array_almost_equal(x, y)
 
 
@@ -122,9 +127,9 @@ class TestSO3(unittest.TestCase):
 
     def test_about(self):
         R = SO3()
-        R.about()
+        R.about
 
-    def test_display(self):
+    def test_str(self):
         R = SO3()
 
         s = str(R)
@@ -133,12 +138,31 @@ class TestSO3(unittest.TestCase):
 
         s = repr(R)
         self.assertIsInstance(s, str)
-        self.assertEqual(s.count('\n'), 3)
-
-        R.print()
+        self.assertEqual(s.count('\n'), 2)
 
+    def test_printline(self):
+        
+        R = SO3.Rx( 0.3)
+        
         R.printline()
+        s = R.printline(file=None)
+        self.assertIsInstance(s, str)
 
+        R = SO3.Rx([0.3, 0.4, 0.5])
+        s = R.printline(file=None)
+        self.assertIsInstance(s, str)
+        self.assertEqual(s.count('\n'), 2)
+        
+    def test_plot(self):
+        plt.close('all')
+        
+        R = SO3.Rx( 0.3)
+        R.plot(block=False)
+        
+        R2 = SO3.Rx(0.6)
+        R.animate()
+        R.animate(start=R.inv())
+        
     def test_listpowers(self):
         R = SO3()
         R1 = SO3.Rx(0.2)
@@ -191,7 +215,7 @@ class TestSO3(unittest.TestCase):
         nt.assert_equal(R.shape, (3, 3))
 
         R = SO3.Rx(0.3)
-        array_compare(R.inv * R, np.eye(3, 3))
+        array_compare(R.inv() * R, np.eye(3, 3))
 
     def test_arith(self):
         R = SO3()
@@ -218,14 +242,7 @@ class TestSO3(unittest.TestCase):
         # array_compare(a, np.array([ [2,0,0], [0,2,0], [0,0,2]]))
         #  this invokes the __add__ method for numpy
 
-        R += R
-        self.assertNotIsInstance(a, SO3)
-        array_compare(a, np.array([[2, 0, 0], [0, 2, 0], [0, 0, 2]]))
 
-        R = SO3()
-        R += 1
-        self.assertNotIsInstance(R, SO3)
-        array_compare(R, np.array([[2, 1, 1], [1, 2, 1], [1, 1, 2]]))
 
         # difference
         R = SO3()
@@ -250,15 +267,6 @@ class TestSO3(unittest.TestCase):
         # self.assertNotIsInstance(a, SO3)
         # array_compare(a, np.zeros((3,3)))
 
-        R -= R
-        self.assertNotIsInstance(R, SO3)
-        array_compare(R, np.zeros((3, 3)))
-
-        R = SO3()
-        R -= 1
-        self.assertNotIsInstance(R, SO3)
-        array_compare(R, np.array([[0, -1, -1], [-1, 0, -1], [-1, -1, 0]]))
-
         # multiply
         R = SO3()
 
@@ -522,37 +530,6 @@ class TestSO3(unittest.TestCase):
         array_compare(a[1], ry + 1)
         array_compare(a[2], rz + 1)
 
-        a = R
-        a += rx
-        self.assertNotIsInstance(a, SO3)
-        nt.assert_equal(len(a), 3)
-        array_compare(a[0], rx + rx)
-        array_compare(a[1], ry + rx)
-        array_compare(a[2], rz + rx)
-
-        a = rx
-        a += R
-        self.assertNotIsInstance(a, SO3)
-        nt.assert_equal(len(a), 3)
-        array_compare(a[0], rx + rx)
-        array_compare(a[1], rx + ry)
-        array_compare(a[2], rx + rz)
-
-        a = R
-        a += R
-        self.assertNotIsInstance(a, SO3)
-        nt.assert_equal(len(a), 3)
-        array_compare(a[0], rx + rx)
-        array_compare(a[1], ry + ry)
-        array_compare(a[2], rz + rz)
-
-        a = R
-        a += 1
-        self.assertNotIsInstance(a, SO3)
-        nt.assert_equal(len(a), 3)
-        array_compare(a[0], rx + 1)
-        array_compare(a[1], ry + 1)
-        array_compare(a[2], rz + 1)
 
         # subtract
         R = SO3([rx, ry, rz])
@@ -577,44 +554,7 @@ class TestSO3(unittest.TestCase):
         array_compare(a[1], ry - ry)
         array_compare(a[2], rz - rz)
 
-        a = R - 1
-        self.assertNotIsInstance(a, SO3)
-        nt.assert_equal(len(a), 3)
-        array_compare(a[0], rx - 1)
-        array_compare(a[1], ry - 1)
-        array_compare(a[2], rz - 1)
 
-        a = R
-        a -= rx
-        self.assertNotIsInstance(a, SO3)
-        nt.assert_equal(len(a), 3)
-        array_compare(a[0], rx - rx)
-        array_compare(a[1], ry - rx)
-        array_compare(a[2], rz - rx)
-
-        a = rx
-        a -= R
-        self.assertNotIsInstance(a, SO3)
-        nt.assert_equal(len(a), 3)
-        array_compare(a[0], rx - rx)
-        array_compare(a[1], rx - ry)
-        array_compare(a[2], rx - rz)
-
-        a = R
-        a -= R
-        self.assertNotIsInstance(a, SO3)
-        nt.assert_equal(len(a), 3)
-        array_compare(a[0], rx - rx)
-        array_compare(a[1], ry - ry)
-        array_compare(a[2], rz - rz)
-
-        a = R
-        a -= 1
-        self.assertNotIsInstance(a, SO3)
-        nt.assert_equal(len(a), 3)
-        array_compare(a[0], rx - 1)
-        array_compare(a[1], ry - 1)
-        array_compare(a[2], rz - 1)
 
     def test_functions(self):
         # inv
@@ -815,16 +755,6 @@ class TestSE3(unittest.TestCase):
         # array_compare(a, np.array([ [2,0,0], [0,2,0], [0,0,2]]))
         #  this invokes the __add__ method for numpy
 
-        a = T
-        a += T
-        self.assertNotIsInstance(a, SE3)
-        array_compare(a, np.array([[2, 0, 0, 2], [0, 2, 0, 4], [0, 0, 2, 6], [0, 0, 0, 2]]))
-
-        a = T
-        a += 1
-        self.assertNotIsInstance(a, SE3)
-        array_compare(a, np.array([[2, 1, 1, 2], [1, 2, 1, 3], [1, 1, 2, 4], [1, 1, 1, 2]]))
-
         # difference
         T = SE3(1, 2, 3)
 
@@ -853,11 +783,6 @@ class TestSE3(unittest.TestCase):
         self.assertNotIsInstance(a, SE3)
         array_compare(a, np.zeros((4, 4)))
 
-        a = T
-        a -= 1
-        self.assertNotIsInstance(a, SE3)
-        array_compare(a, np.array([[0, -1, -1, 0], [-1, 0, -1, 1], [-1, -1, 0, 2], [-1, -1, -1, 0]]))
-
         # multiply
         T = SE3(1, 2, 3)
 
@@ -1101,38 +1026,6 @@ class TestSE3(unittest.TestCase):
         array_compare(a[1], ry + 1)
         array_compare(a[2], rz + 1)
 
-        a = T
-        a += rx
-        self.assertNotIsInstance(a, SE3)
-        nt.assert_equal(len(a), 3)
-        array_compare(a[0], rx + rx)
-        array_compare(a[1], ry + rx)
-        array_compare(a[2], rz + rx)
-
-        a = rx
-        a += T
-        self.assertNotIsInstance(a, SE3)
-        nt.assert_equal(len(a), 3)
-        array_compare(a[0], rx + rx)
-        array_compare(a[1], rx + ry)
-        array_compare(a[2], rx + rz)
-
-        a = T
-        a += T
-        self.assertNotIsInstance(a, SE3)
-        nt.assert_equal(len(a), 3)
-        array_compare(a[0], rx + rx)
-        array_compare(a[1], ry + ry)
-        array_compare(a[2], rz + rz)
-
-        a = T
-        a += 1
-        self.assertNotIsInstance(a, SE3)
-        nt.assert_equal(len(a), 3)
-        array_compare(a[0], rx + 1)
-        array_compare(a[1], ry + 1)
-        array_compare(a[2], rz + 1)
-
         # subtract
         T = SE3([rx, ry, rz])
         a = T - rx
@@ -1163,37 +1056,6 @@ class TestSE3(unittest.TestCase):
         array_compare(a[1], ry - 1)
         array_compare(a[2], rz - 1)
 
-        a = T
-        a -= rx
-        self.assertNotIsInstance(a, SE3)
-        nt.assert_equal(len(a), 3)
-        array_compare(a[0], rx - rx)
-        array_compare(a[1], ry - rx)
-        array_compare(a[2], rz - rx)
-
-        a = rx
-        a -= T
-        self.assertNotIsInstance(a, SE3)
-        nt.assert_equal(len(a), 3)
-        array_compare(a[0], rx - rx)
-        array_compare(a[1], rx - ry)
-        array_compare(a[2], rx - rz)
-
-        a = T
-        a -= T
-        self.assertNotIsInstance(a, SE3)
-        nt.assert_equal(len(a), 3)
-        array_compare(a[0], rx - rx)
-        array_compare(a[1], ry - ry)
-        array_compare(a[2], rz - rz)
-
-        a = T
-        a -= 1
-        self.assertNotIsInstance(a, SE3)
-        nt.assert_equal(len(a), 3)
-        array_compare(a[0], rx - 1)
-        array_compare(a[1], ry - 1)
-        array_compare(a[2], rz - 1)
 
     def test_functions(self):
         # inv
@@ -1205,8 +1067,7 @@ class TestSE3(unittest.TestCase):
         # .T
         pass
 
-
 # ---------------------------------------------------------------------------------------#
 if __name__ == '__main__':
-
+    
     unittest.main()
